@@ -1,5 +1,5 @@
 #!/usr/bin/env perl
-package Bio::RetreveAssemblies;
+package Bio::RetrieveAssemblies;
 use Moose;
 use File::Path qw(make_path);
 # ABSTRACT: Get assemblies for a project accession
@@ -98,7 +98,7 @@ retrieve_assemblies - Get assemblies for a project accession
 
 =head1 VERSION
 
-version 0.0.1
+version 0.0.2
 
 =head1 SYNOPSIS
 
